ret2script::modules::bucket

Struct Bucket

pub struct Bucket { /* private fields */ }
the bucket instance.

Implementations

Source

impl Bucket

pub fn try_new(path: impl AsRef<Path>) -> Result<Self, Error>

init a new bucket instance, the path in args defines bucket root, any file operation in this bucket must under the root path.